# Finds information about a release export
#
# ./check_export_status.sh <folder>
#
# Outputs a JSON data structure with information about the export
# 
# Exists with exit code=99 if the data folder doesn't exists
# or contains the expected data file
#

# The folder to check is the first parameter 
# (or it may exists as a global variable already)
if [ $# -ne 0 ]; then
	DATA_FOLDER=$1
fi

if [ ! -d "${DATA_FOLDER}" ]; then
	echo "Can't find data folder ${DATA_FOLDER}" 1>&2
	exit 99
fi

# Format string for file dates/times
DATE_FORMAT="%Y%m%d %H%M%S"

INDEX_JSON=${DATA_FOLDER}/index.json 

if [ ! -f "${INDEX_JSON}" ]; then
	echo "Can't find data folder ${DATA_FOLDER}" 1>&2
	exit 99
fi


# Start a JSON object
echo "{"

# index.json is one of the first files created 
# and contains some metadata about the export
if [ -f "${INDEX_JSON}" ]; then
	echo "\"index\":`cat "${INDEX_JSON}"`,"
	echo "\"startdate\": \"`date +"${DATE_FORMAT}" -r "${INDEX_JSON}"`\","
fi

# The ./json subfolder contains the JSON files for all items
if [ -d "${DATA_FOLDER}/json" ]; then
	echo "\"jsoncount\": `find "${DATA_FOLDER}/json" -type f -name *.json | wc -l`"
fi

# 'exportcomplete' is created when the export is complete
if [ -f "${DATA_FOLDER}/exportcomplete" ]; then
	echo "\"enddate\": \"`date +"${DATE_FORMAT}" -r "${DATA_FOLDER}/exportcomplete"`\","
fi

# End the main JSON object
echo "}"
